@@ -33,9 +33,10 @@
 #  define LIBKDCRAW_DEPRECATED_NO_EXPORT LIBKDCRAW_NO_EXPORT LIBKDCRAW_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define LIBKDCRAW_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef LIBKDCRAW_NO_DEPRECATED
+#    define LIBKDCRAW_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
